pub struct Func<T>(/* private fields */);Expand description
A function value, this can be called with a set of positional arguments to produce a value. This is most commonly used as a constructor for tests sets.
Implementations
Sourceimpl<T> Func<T>
impl<T> Func<T>
Sourceimpl<T> Func<T>
impl<T> Func<T>
Sourcepub fn expect_no_args(
id: &str,
_ctx: &Context<T>,
args: &[Value<T>],
) -> Result<(), Error>
pub fn expect_no_args( id: &str, _ctx: &Context<T>, args: &[Value<T>], ) -> Result<(), Error>
Ensure there are no args.