Set

Struct Set 

pub struct Set<T>(/* private fields */);
A test set, this can be used to check if a test is contained in it and is expected to be the top level value in an ExpressionFilter.

Implementations

Source

impl<T> Set<T>

pub fn new<F>(f: F) -> Self
where F: Fn(&Context<T>, &T) -> Result<bool, Error> + Send + Sync + 'static,

Create a new set with the given implementation.

pub fn contains(&self, ctx: &Context<T>, test: &T) -> Result<bool, Error>

Whether the given test is contained within this set.

Source

impl<T: Test> Set<T>

pub fn coerce_pat(pat: Pat) -> Set<T>

Construct a test set which contains all tests matching the given pattern.

This is the test set created from pattern literals like r:'foot-(\w-)+'.

Source

impl<T: 'static> Set<T>

pub fn expr_comp(set: Set<T>) -> Self

Construct a set which contains all tests not contained in the given set.

This is the test set created by !set.

pub fn expr_union<I>(a: Set<T>, b: Set<T>, rest: I) -> Self
where I: IntoIterator<Item = Set<T>>,

Construct a set which contains all tests which are contained in any of the given sets.

This is the test set created by a | b.

pub fn expr_inter<I>(a: Set<T>, b: Set<T>, rest: I) -> Self
where I: IntoIterator<Item = Set<T>>,

Construct a set which contains all tests which are contained in all the given sets.

This is the test set created by a & b.

pub fn expr_diff(a: Set<T>, b: Set<T>) -> Self

Construct a set which contains all tests which are contained in the first but not the second set.

This is the test set created by a ~ b and is equivalent to a & !b.

pub fn expr_sym_diff(a: Set<T>, b: Set<T>) -> Self

Construct a set which contains all tests which are contained in the either the first or the second, but not both sets.

This is the test set created by a ^ b.