ExpressionFilter

Struct ExpressionFilter 

pub struct ExpressionFilter<T: 'static> { /* private fields */ }
A generic test set expression filter, this filter checks whether a test should be filtered out by checking it against the inner test set within its evaluation context.

This also includes extra parsing logic for the special all: modifier prefix, which is not part of the test set grammar, but can be used by the caller to handle instances where multiple tests match but only one is usually expected.

Implementations

Source

impl<T: Test> ExpressionFilter<T>

pub fn new<S: Into<EcoString>>(ctx: Context<T>, input: S) -> Result<Self, Error>

Parse and evaluate a string into a test set with the given context.

Source

impl<T> ExpressionFilter<T>

pub fn input(&self) -> &str

The input expression the inner test set was parsed from.

pub fn all(&self) -> bool

Whether this test set expression has the special all: modifier.

Handling this is up to the caller and has no impact on the inner test set.

pub fn ctx(&self) -> &Context<T>

The context used to evaluate the inner test set.

pub fn set(&self) -> &Set<T>

The inner test set.

Source

impl<T> ExpressionFilter<T>

pub fn map<F>(self, f: F) -> Self
where F: FnOnce(Set<T>) -> Set<T>,

Applies a function to the inner test set, this is useful for optimization or for adding implicit test sets like wrapping a test set in (...) ~ skip().

Source

impl<T> ExpressionFilter<T>

pub fn contains(&self, test: &T) -> Result<bool, Error>

Whether the given test is contained in this test set. Note that this means a return value of true should not be filtered out, but included in the set of tests to operate on.