pub struct Set<T>(/* private fields */);Expand description
A test set, this can be used to check if a test is contained in it and is
expected to be the top level value in an ExpressionFilter.
Implementations
Sourceimpl<T: Test> Set<T>
impl<T: Test> Set<T>
Sourcepub fn coerce_pat(pat: Pat) -> Set<T>
pub fn coerce_pat(pat: Pat) -> Set<T>
Construct a test set which contains all tests matching the given pattern.
This is the test set created from pattern literals like r:'foot-(\w-)+'.
Sourceimpl<T: 'static> Set<T>
impl<T: 'static> Set<T>
Sourcepub fn expr_comp(set: Set<T>) -> Self
pub fn expr_comp(set: Set<T>) -> Self
Construct a set which contains all tests not contained in the given set.
This is the test set created by !set.
Sourcepub fn expr_union<I>(a: Set<T>, b: Set<T>, rest: I) -> Selfwhere
I: IntoIterator<Item = Set<T>>,
pub fn expr_union<I>(a: Set<T>, b: Set<T>, rest: I) -> Selfwhere
I: IntoIterator<Item = Set<T>>,
Construct a set which contains all tests which are contained in any of the given sets.
This is the test set created by a | b.
Sourcepub fn expr_inter<I>(a: Set<T>, b: Set<T>, rest: I) -> Selfwhere
I: IntoIterator<Item = Set<T>>,
pub fn expr_inter<I>(a: Set<T>, b: Set<T>, rest: I) -> Selfwhere
I: IntoIterator<Item = Set<T>>,
Construct a set which contains all tests which are contained in all of the given sets.
This is the test set created by a & b.
Sourcepub fn expr_diff(a: Set<T>, b: Set<T>) -> Self
pub fn expr_diff(a: Set<T>, b: Set<T>) -> Self
Construct a set which contains all tests which are contained in the first but not the second set.
This is the test set created by a ~ b and is equivalent to a & !b.
Sourcepub fn expr_sym_diff(a: Set<T>, b: Set<T>) -> Self
pub fn expr_sym_diff(a: Set<T>, b: Set<T>) -> Self
Construct a set which contains all tests which are contained in the either the first or the second, but not both sets.
This is the test set created by a ^ b.