Trait Test

pub trait Test: Clone + 'static {
    // Required method
    fn id(&self) -> &str;
}
A marker trait for tests, this is automatically implemented for all clonable static types.

Required Methods

fn id(&self) -> &str

The id of a test, this is used for matching on tests using test sets created from pattern literals.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors