pub struct ExpressionFilter<T: 'static> { /* private fields */ }Expand description
A generic test set expression filter, this filter checks whether a test should be filtered out by checking it against the inner test set within its evaluation context.
This also includes extra parsing logic for the special all: modifier
prefix, which is not part of the test set grammar, but can be used by the
caller to handle instances where multiple tests match but only one is
usually expected.
Implementations
Sourceimpl<T: Test> ExpressionFilter<T>
impl<T: Test> ExpressionFilter<T>
Sourceimpl<T> ExpressionFilter<T>
impl<T> ExpressionFilter<T>
Sourceimpl<T> ExpressionFilter<T>
impl<T> ExpressionFilter<T>